==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1LimitRangeFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface V1LimitRangeFluent<A extends V1LimitRangeFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ObjectMeta getMetadata();
    public V1ObjectMeta buildMetadata();
    public A withMetadata(V1ObjectMeta metadata);
    public Boolean hasMetadata();
    public V1LimitRangeFluent.MetadataNested<A> withNewMetadata();
    public V1LimitRangeFluent.MetadataNested<A> withNewMetadataLike(V1ObjectMeta item);
    public V1LimitRangeFluent.MetadataNested<A> editMetadata();
    public V1LimitRangeFluent.MetadataNested<A> editOrNewMetadata();
    public V1LimitRangeFluent.MetadataNested<A> editOrNewMetadataLike(V1ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public V1LimitRangeSpec getSpec();
    public V1LimitRangeSpec buildSpec();
    public A withSpec(V1LimitRangeSpec spec);
    public Boolean hasSpec();
    public V1LimitRangeFluent.SpecNested<A> withNewSpec();
    public V1LimitRangeFluent.SpecNested<A> withNewSpecLike(V1LimitRangeSpec item);
    public V1LimitRangeFluent.SpecNested<A> editSpec();
    public V1LimitRangeFluent.SpecNested<A> editOrNewSpec();
    public V1LimitRangeFluent.SpecNested<A> editOrNewSpecLike(V1LimitRangeSpec item);

    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ObjectMetaFluent<V1LimitRangeFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface SpecNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1LimitRangeSpecFluent<V1LimitRangeFluent.SpecNested<N>>{

        
    public N and();    public N endSpec();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1LimitRangeFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface V1LimitRangeFluent<A extends V1LimitRangeFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ObjectMeta getMetadata();
    public V1ObjectMeta buildMetadata();
    public A withMetadata(V1ObjectMeta metadata);
    public Boolean hasMetadata();
    public V1LimitRangeFluent.MetadataNested<A> withNewMetadata();
    public V1LimitRangeFluent.MetadataNested<A> withNewMetadataLike(V1ObjectMeta item);
    public V1LimitRangeFluent.MetadataNested<A> editMetadata();
    public V1LimitRangeFluent.MetadataNested<A> editOrNewMetadata();
    public V1LimitRangeFluent.MetadataNested<A> editOrNewMetadataLike(V1ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public V1LimitRangeSpec getSpec();
    public V1LimitRangeSpec buildSpec();
    public A withSpec(V1LimitRangeSpec spec);
    public Boolean hasSpec();
    public V1LimitRangeFluent.SpecNested<A> withNewSpec();
    public V1LimitRangeFluent.SpecNested<A> withNewSpecLike(V1LimitRangeSpec item);
    public V1LimitRangeFluent.SpecNested<A> editSpec();
    public V1LimitRangeFluent.SpecNested<A> editOrNewSpec();
    public V1LimitRangeFluent.SpecNested<A> editOrNewSpecLike(V1LimitRangeSpec item);

    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ObjectMetaFluent<V1LimitRangeFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface SpecNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1LimitRangeSpecFluent<V1LimitRangeFluent.SpecNested<N>>{

        
    public N and();    public N endSpec();
}


}
